package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````52(```````!``````````#BQ````
M`````````$``.``-`$``&0`8``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````9`````````!D``````````0`````````!````
M!````````````````````````````````````$@8````````2!@`````````
M$`````````$````%`````"``````````(``````````@````````(#L`````
M```@.P`````````0`````````0````0`````8`````````!@`````````&``
M``````!X1P```````'A'`````````!`````````!````!@```/BK````````
M^+L```````#XNP```````"@$````````N`0`````````$`````````(````&
M````$*P````````0O````````!"\````````X`$```````#@`0````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````"0`````````)``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``"PH````````+"@````````L*````````#L`````````.P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````^*L```````#XNP```````/B[````
M````"`0````````(!`````````$`````````+VQI8B]L9"UM=7-L+7@X-E\V
M-"YS;RXQ```````````$````(`````4```!'3E4``0`!P`0````)````````
M``(``<`$`````0`````````$````%`````,```!'3E4`.59H&RT)J_;]$)[8
MEXF[+V.II<H`````$0```$`````$````"````"`<$``%0`2"*``0!("&`(2"
MH0`B20($";B"&$&Z!`(*0````$$```!%````20```$H```!1````4@```%0`
M````````6````%D```!:````6P```%P```!>``````````````"CZ1D$SMY'
M+6[%WQ]J?YI\Z]/O#B[%F[:XC?$.(/_D#M5DU'S9<5@<L@&+;YA/PYO"Y3\L
M0OK7A_JA;&"ZXY)\XT?&`57#/-)FK\QFQ;F<0(@'<-/$B060./*+'$-%U>PS
M8MOM%8PES*?=HVM_J9R;X*<""FL:GE"BX/M)"XH05P``````````````````
M``````````````````!V`@``$@````````````````````````";`0``$@``
M``````````````````````!2````$@````````````````````````"\`@``
M$@````````````````````````!O`0``$@`````````````````````````]
M````$@`````````````````````````9`0``$@``````````````````````
M``#>`0``$@````````````````````````"J````$@``````````````````
M``````"S````(@`````````````````````````X`0``$@``````````````
M``````````##`0``$@````````````````````````!D`@``$@``````````
M``````````````"``0``$@````````````````````````#\````$@``````
M``````````````````!]`@``$@`````````````````````````W````$@``
M```````````````````````G`0``$@````````````````````````!-`@``
M$@````````````````````````!B````$@````````````````````````#]
M`0``$@````````````````````````";````$@``````````````````````
M```D`@``$@`````````````````````````?````(```````````````````
M``````!-`0``$@````````````````````````#=````(```````````````
M``````````!J````$@````````````````````````#W````$@``````````
M``````````````!:````$@````````````````````````!+````$@``````
M```````````````````0````$@`````````````````````````;`@``$@``
M``````````````````````"4`@``$@````````````````````````"/`0``
M$@````````````````````````!Y````(`````````````````````````"-
M`@``$@`````````````````````````]`@``$@``````````````````````
M``#J`0``$@`````````````````````````!````$@``````````````````
M``````!$````$@````````````````````````#R`P``$@``````````````
M```````````O`@``$@````````````````````````"%`@``$@``````````
M```````````````+`@``$@````````````````````````!K````$@``````
M``````````````````!K`@``$@`````````````````````````8````$@``
M```````````````````````"`0``$@````````````````````````#8````
M$@````````````````````````!<`0``%@````````````````````````";
M`@``$@````````````````````````"J`@``$@``````````````````````
M```@`0``$@````````````````````````"5````$@``````````````````
M``````"C````$@````````````````````````!P````$@``````````````
M```````````_`0``$@````````````````````````!8`@``$@``````````
M```````````````3`0``$@````````````````````````#"````(```````
M``````````````````#4`0``$@````````````````````````":````$@``
M``````````````````````#9`0``$@````````````````````````#%`@``
M(0`6`"#`````````"`````````!Z`P``$@`+`*`U````````]`8```````"'
M`P``$@`+`/`^````````T@````````"W`@``$@`+`$`@````````%0(`````
M``"P`0``$@`,`!U;`````````0````````#^`@``$@`+`&`J````````!0``
M``````#^`P``$@`)```@`````````0`````````S`P``$@`+`'`J````````
M'P(```````!(`P``$@`+`*`\````````30(```````"3`P``$``6`"#`````
M```````````````9`P``$@`+`$`R````````8@````````!``P``$@`+`+`R
M````````L0````````!>`P``$@`+```I````````)@````````!O`P``$@`+
M`)!6````````.@(```````"?`P``$@`+`-`T````````Q0````````#.`P``
M$``6`+#```````````````````#3`P``$@`+`)`L````````)`````````!F
M`P``$@`+`&LB````````(P`````````G`P``$@`+`,`L````````$@$`````
M``#&`@``$0`6`"#`````````"``````````/`P``$0`5`!C`````````"```
M``````#'`@``(0`6`"#`````````"``````````)````$0`2``B\````````
M"`````````#'`P``$``5`"#```````````````````"8`P``$``+`%4B````
M``````````````#[`P``$@`+`$!6````````1@````````#(`@``(0`6`"#`
M````````"`````````#@`P``$@`+`+`T````````'P````````"Q`P``$@`+
M`#`I````````*@$````````$!```$@`+`-!8````````30(```````#Q`@``
M$@`+`.`M````````700```````"V`0``$0`6`"C``````````0``````````
M;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`7U]D97)E9VES=&5R7V9R
M86UE7VEN9F\`;'-E96L`9V5T<&ED`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S
M=')N8VUP`'-T<G)C:'(`;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`=F9P<FEN=&8`<W1R8VAR`')E861L:6YK`%]?
M8WAA7V9I;F%L:7IE`%]?<F5G:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?
M<F5G:7-T97)434-L;VYE5&%B;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T
M:6]N`&UK9&ER`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U
M:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O
M;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E
M=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``
M4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A
M=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E
M<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S
M=')C<'D`<F5A9&1I<@!S<')I;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A
M=&9O<FL`7U]L:6)C7W-T87)T7VUA:6X`<VYP<FEN=&8`7U]?96YV:7)O;@!L
M:6)P97)L+G-O`&QI8F,N;75S;"UX.#9?-C0N<V\N,0!P87)?:6YI=%]E;G8`
M<&%R7V-U<G)E;G1?97AE8P!M>5]P87)?<&P`<&%R7V5N=E]C;&5A;@!P87)?
M9&ER;F%M90!P87)?9FEN9'!R;V<`<&%R7V1I90!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`>'-?:6YI=`!?<W1A<G1?8P!S:&%?=7!D871E`'!A<E]M:W1M<&1I
M<@!P87)?8VQE86YU<`!?7V)S<U]S=&%R=`!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`7V5D871A`%]E;F0`<&%R7V)A<V5N86UE
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'-H85]I;FET`'-H85]F:6YA
M;``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``````^+L````````(
M`````````&`C`````````+P````````(```````````C`````````,``````
M```(``````````#`````````&,`````````(`````````.AB````````$+X`
M```````&`````0``````````````&+X````````&`````@``````````````
M(+X````````&`````P``````````````*+X````````&````!```````````
M````,+X````````&````!0``````````````.+X````````&````!@``````
M````````0+X````````&````!P``````````````2+X````````&````"```
M````````````4+X````````&````"0``````````````6+X````````&````
M"@``````````````8+X````````&````"P``````````````:+X````````&
M````#```````````````<+X````````&````#0``````````````>+X`````
M```&````#@``````````````@+X````````&````#P``````````````B+X`
M```````&````$```````````````D+X````````&````$0``````````````
MF+X````````&````$@``````````````H+X````````&````$P``````````
M````J+X````````&````%```````````````L+X````````&````%0``````
M````````N+X````````&````%@``````````````P+X````````&````%P``
M````````````R+X````````&````&```````````````T+X````````&````
M&0``````````````V+X````````&````&@``````````````X+X````````&
M````&P``````````````Z+X````````&````'```````````````\+X`````
M```&````'0``````````````^+X````````&````'@```````````````+\`
M```````&````'P``````````````"+\````````&````(```````````````
M$+\````````&````(0``````````````&+\````````&````(@``````````
M````(+\````````&````(P``````````````*+\````````&````)```````
M````````,+\````````&````)0``````````````.+\````````&````)@``
M````````````0+\````````&````)P``````````````2+\````````&````
M*```````````````4+\````````&````*0``````````````6+\````````&
M````*@``````````````8+\````````&````*P``````````````:+\`````
M```&````+```````````````<+\````````&````+0``````````````>+\`
M```````&````+@``````````````@+\````````&````+P``````````````
MB+\````````&````,```````````````D+\````````&````,0``````````
M````F+\````````2````,@``````````````H+\````````&````,P``````
M````````J+\````````&````-0``````````````L+\````````&````-@``
M````````````N+\````````&````-P``````````````P+\````````&````
M.```````````````R+\````````&````.0``````````````T+\````````&
M````.@``````````````V+\````````&````.P``````````````X+\`````
M```&````/```````````````Z+\````````&````/0``````````````\+\`
M```````&````/@``````````````^+\````````&````/P``````````````
M"+P````````%````5@``````````````(,`````````%````4P``````````
M````*,`````````%````7P``````````````"+X````````'````-```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!06,,`````````````````_S7BG0``_R7DG0``#Q]``/\EXIT``&@`````
MZ>#___\/"P\+9BX/'X0``````&:055-(@^PXB7PD'$B-?"0<2(ET)!!(C70D
M$$B)5"0(2(U4)`AD2(L$)2@```!(B40D*#'`_Q57G@``2(LUN)X``$B+/:F=
M``!(B?+_%1"?``"`/9&?````#X0?`0``2(L%])X``&1(BP"`B#H$```#BT0D
M'(UX!(U8`TAC_TC!YP/_%0J?``!(BWPD$$2+1"0<2(G!2(D%QI\``$B+!TB)
M`4B-!?%```!(B4$(2(L%)I\``$B)01!(C07>0```2(E!&$&#^`$/CB\!``!(
M@\<(08/``[H$````#Q^$``````!(BP=(8_*#P@%(@\<(2(D$\40YPG7J2&/2
M13'`2(L]99\``$B--68'``!(QP31`````(G:_Q5&G0``A<`/A(P```!(BST_
MGP``2(UL)"3_%>2=``!(B>Y(C3T6/P``B<,QP.@9`@``2(7`='1(BST5GP``
M_Q5/G@``_Q4IG@``2(M$)"AD2"L$)2@````/A9P```!(@\0XB=A;7</_%;:=
M``!(B07?G@``2(G'2(7`='/_%:&<``!(BP6ZG0``9$B+$,:"]@@```#IMO[_
M_TB+/;.>``#_%0V=``#I8O___TB+/9&>``!(A?]T"NC?'```Z7;___](C3TL
M/@``2(GNZ'L!``!(B05LG@``2(G'2(7`#X14____Z]*Z!````.GR_O__OP$`
M``#_%4&=``#_%4.<``!(,>U(B>=(C36NF0``2(/D\.@`````BS=(C5<(3(T%
MI3@``$4QR4B-#7[]__](C3VW_?__Z9+]__]FD$B-/8F=``!(C06"G0``2#GX
M=!5(BP5VG```2(7`=`G_X`\?@`````###Q^``````$B-/5F=``!(C352G0``
M2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!>V;``!(A<!T"/_@9@\?1```PP\?
M@`````"`/3F=````=4=52(,]1IL```!(B>5T#4B+/>*<``#_%32;``#H9___
M_TB#/9>;````=`U(C3VF?@``_Q6(FP``Q@7YG````5W##Q^``````,-F9BX/
M'X0```````\?0`!(@SUXG````'0F54B-->Z<``!(C3UG?@``2(GE_Q5>G```
M7>DX____#Q^$``````#I*____V8N#Q^$``````"005=!5D%505154TB#[`A(
MA?\/A+$```!,BS5BG```387V#X2A````#[8'28G_28GUA,!T!#P]=5A%,>1)
MBQY(A=MT-$UCY$R)]0\?@`````!,B>),B?Y(B=__%?&:``"%P'4'0H`\(SUT
M1DB+70A(@\4(2(7;==E(@\0(2(G86UU!7$%=05Y!7\,/'X``````28G\00^V
M1"0!28/$`83`=`0\/77N12G\ZY%F#Q]$``!,*?5*C5PC`4C!_0-!B6T`Z[5F
M#Q]$```QV^NK#Q]``%-(B?M(@>R@````9$B+!"4H````2(F$))@````QP$B)
MYO\529H``(7`=36+5"08@>(`\```@?H`0```=`B!^@"@``!U';X"````2(G?
M_Q6]F@``A<`/E,`/ML#K!0\?`#'`2(N4))@```!D2"L4)2@```!U"4B!Q*``
M``!;P_\5I)D``&9F+@\?A```````D$%505154TB![*@```!D2(L$)2@```!(
MB80DF````#'`2(7_=`B`/P!(B?MU*TB+A"28````9$@K!"4H````#X4C`0``
M2('$J````%M=05Q!7<-F#Q]$``#_%>*9``!(B<5(A<!TQTB)[_\5&9D``$B%
MP`^$J````(!X$RY,C6`3=0Y!@'PD`0!TW&8/'T0``(!X$RX/A*8```!(B=__
M%06:``!,B>=)B<7_%?F9``!!C7P%`DAC__\5LY@``$R)X4B)VDB--38Z``!)
MB<5(B<<QP/\5B)D``$R)[TB)YO\5C)D``$R)[X/X_W00BT0D&"4`\```/0!`
M``!T9/\5]I@``$R)[_\5[9D``$B)[_\5=)@``$B%P`^%6____P\?`$B)[_\5
MEYD``$B)W_\53I@``.GV_O__9@\?A```````08!\)`$N#X5.____08!\)`(`
M#X0.____Z3W___\/'P#HF_[__^N;_Q4KF```#Q\`05=!5D%505152(GU4TB)
M^TB#["AD2(L$)2@```!(B40D&#'`,<"`/CT/E,!(`<5(B>__%0"9``!(C70D
M%$B)WTF)Q#'`Z.;\__](A<`/A`4!``!)B<5(B<?_%=F8``!,.>`/@]````!,
M8W0D%$G!Y@,/M@.$P`^$G`$``#P]#X24`0``2(G89@\?A```````#[90`4B#
MP`&$TG0%@/H]=>](*=A(F$R++0.9``!*C7P@`O\52)<``$T!]4F)10!(A<!T
M34B+!>68``!(C4L!2HL4,`^V`X@"/#UU%>L79I`/M@%(@\(!2(/!`8@"/#UT
M!(3`=>O&`CTQP&8/'T0```^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$)2@`
M```/A0<!``!(@\0H6UU!7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`
M2(/``832=>[KO0\?0`!,BSU1F```28,_``^$M@```$R)^$4Q[9!(@\`(1(GJ
M08/%`4B#.`!U[XUR`TAC]DC!Y@.+!8^8``"%P'5;QP6!F````0```$B)]_\5
M6)8``$B%P`^$8/___TUC]4B)1"0(3(G^2(G'2<'F`TR)\O\5Y)4``$B+3"0(
M2(D-V)<``$&-10%$B6PD%$B82,<$P0````#I@?[__TR)__\5EY8``$B)!;"7
M``!(B<%(A<`/A`7___]-8_5)P>8#Z\,/'P`QP.F'_O__OA````!%,>WI7___
M__\5]I4``&9F+@\?A```````#Q\`4TB+'>"6``!(C0VA=P``2(TU0#<``$B+
M%6.6``!D2(L[_Q7IE0``3(T%US@``&1(BSM;13')3(G!2(T5L!,``$B--2LW
M``#_)6N5```/'P!(BP61E@``2(L5(I8``$B-#4MW``!(C37J-@``9$B+./\E
MFI4``&8N#Q^$``````!54TB![``0``!(@PPD`$B![``0``!(@PPD`$B#["AD
M2(L$)2@```!(B80D&"```#'`2(GC_Q7.E```3(T%QC8``+X!$```2(G?B<%(
MC16Y-@``,<#_%9Z4``"#^/\/A+T```!(F$@]`!````^'C_;__TB-K"00$```
M2(G?N@`0``!(B>[_%9:4``!(B<.%P`^(BP```(UX`4AC__\5GY0``$B)P4B%
MP'1W2&/;2#GH<PU(C0082#G%#X)"]O__2#G-<DU(@?L!$```#X<P]O__2(G/
M2(G:2(GN_Q4QE```Q@08`$B)P4B+A"08(```9$@K!"4H````=2M(@<0H(```
M2(G(6UW#9BX/'X0``````$B-1!T`2#G!<ZGIX?7__Y`QR>O"_Q4^E```9@\?
M1```Z<O^__]F9BX/'X0``````$%7059!54%455-(@>P`$```2(,,)`!(@>RX
M````9$B+!"4H````2(F$)*@0```QP$F)_$B)\TB-/9PU``!(C70D#.CI^/__
MOB\```!,B>=(B<7_%?"4``!(A<!T0S'`3(GF2(T]>34``.B2^___3(G@2(N4
M)*@0``!D2"L4)2@````/A9$!``!(@<2X$```6UU!7$%=05Y!7\-F#Q]$``!(
MB=],C2U%-0``3(TU238``/\5`90``$R)[DB)Q_\5W9,``$B)PTB%P'22@#L`
M#X32````#Q]``$B%[7042(G>2(GO_Q7ODP``A<`/A)4```!(B=__%3Z4``!(
MC50#_TF)QT@YTW(5ZR0/'X``````Q@(`2(/J`4@YTW0%@#HO=.](B=__%0Z4
M``!)B<=,B>?_%0*4``!)C40'`4@]_P\```^'%O___TR-O"2@````38GA2(G9
M,<!,C063-```3(GRO@`0``!,B?__%4F2``"#P`$]`!```'9/#PL/'T0``(!]
M`0!U*TR)[C'__Q4/DP``2(G#2(7`#X3`_O__@#L`#X4R____2(7M=`:`?0`N
M=,]!OP$```!(C1T9-```Z6K___\/'T0``$B-="003(G__Q4JDP``A<!UK(M$
M)"@E`/```#T`@```=9R^`0```$R)__\5&),``(7`=8I,B?Y(C3W<,P``Z/7Y
M__],B?__%:22``#I6/[___\5"9(``)!3OB\```!(B?O_%0F2``!(C5`!2(7`
M2`]%VDB)WUO_)722``!F9BX/'X0``````)!54TB![``0``!(@PPD`$B#[!AD
M2(L$)2@```!(B80D"!```#'`2(7_#X2B````@#\`2(G]#X26````_Q6HD@``
M2(/``4@]`!````^'N````$B)XTB)[DB)W_\5\9```$B)W_\5@)(``$B-1`/_
M2#G#<A+K%0\?0`#&``!(@^@!2#G8=`6`."]T[[XO````2(G?_Q51D0``2(7`
M=#1(.<-R7TB)W_\5OI$``$B+E"0($```9$@K%"4H````=4](@<08$```6UW#
M9@\?A```````2(N$)`@0``!D2"L$)2@```!U*4B!Q!@0``!(C3V6,@``6UW_
M)6^1```/'X``````Q@``ZYP/'P`QP.N>_Q7&D```9F8N#Q^$```````/'P!!
M5T%6055!5%5(C2US,@``4TB#[!AD2(L$)2@```!(B40D"#'`2(U<)`1F#Q]$
M```QP$B)WDB)[^B#]?__2(7`=#9(8U0D!$B+!?*1``!(C0302(M0"$B)$$B%
MTG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(C2T-,@``D#'`2(G>2(GO
MZ#/U__](A<!T-DAC5"0$2(L%HI$``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(
M@\`(2(D02(72=?#KOF8/'T0``$B-+<4Q``"0,<!(B=Y(B>_HX_3__TB%P'0V
M2&-4)`1(BP52D0``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```2(TM?C$``)`QP$B)WDB)[^B3]/__2(7`=#9(8U0D!$B+!0*1
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!(
MC2TU,0``D#'`2(G>2(GOZ$/T__](A<!T-DAC5"0$2(L%LI```$B-!-!(BU`(
M2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-)?4P``"0,<!(
MB=Y,B>?H\_/__TB%P'0V2&-4)`1(BP5BD```2(T$T$B+4`A(B1!(A=)TTF:0
M2(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(TE6C```)`QP$B)WDR)Y^BC\___
M2(7`=#9(8U0D!$B+!1*0``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)
M$$B%TG7PZ[YF#Q]$``!,C35A,```D#'`2(G>3(GWZ%/S__](A<!T-DAC5"0$
M2(L%PH\``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/
M'T0``$R-+1LP``"0,<!(B=Y,B>_H`_/__TB%P'0V2&-4)`1(BP5RCP``2(T$
MT$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(T]U2\`
M`)`QP$B)WDR)_^BS\O__2(7`=#9(8U0D!$B+!2*/``!(C0302(M0"$B)$$B%
MTG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C3TC+P``D#'`2(G>3(G_
MZ&/R__](A<!T-DAC5"0$2(L%THX``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(
M@\`(2(D02(72=?#KOF8/'T0``$B)WDB-/3PO``#H&?+__TB%P'0-2(G&3(GO
M,<#HU_3__S'`2(G>2(T]*B\``.CV\?__2(7`=!%(B<9(C3TH+P``,<#HL/3_
M_TB)WDB-/2(O```QP.C/\?__2(G&2(7`=#E,B><QP.B-]/__2(M$)`AD2"L$
M)2@```!U1$B#Q!A(B>](C34,+P``,<!;74%<05U!7D%?Z5[T__\QP$B)WDB-
M/=XN``#H??'__TB%P'2[2(G&3(GW,<#H._3__^NL_Q5;C```#Q\`2(/L&$B-
M/54N``!D2(L$)2@```!(B40D"#'`2(UT)`3H._'__TB%P'0N#[80@/HP#Y3`
MA-(/E,()T(/P`0^VP$B+5"0(9$@K%"4H````=0Q(@\08PP\?`#'`Z^3_%?:+
M``!F9BX/'X0```````\?`%!82('LV````$B)="0H2(E4)#!(B4PD.$R)1"1`
M3(E,)$B$P'0W#RE$)%`/*4PD8`\I5"1P#RF<)(`````/*:0DD`````\IK"2@
M````#RFT)+`````/*;PDP````&1(BP0E*````$B)1"08,<!(C80DX````$B)
M_DB)XDB)1"0(2(U$)"!(BSW,B```QP0D"````,=$)`0P````2(E$)!#_%9J,
M``"__P```/\5+XP``&9F+@\?A```````#Q]``$%455-,C9PD``#__TB![``0
M``!(@PPD`$PYW'7O2(/L$+H"````,?9D2(L$)2@```!(B80D"``!`#'`08G\
M2(GC_Q79B@``2(UH_TB)ZDC!^C](P>HP2(U$%0`/M\!(*=!(*<4/B*H```!F
M#Q]$```QTDB)[D2)Y_\5HHH``$B#^/\/A*,```"Z"``!`$B)WD2)Y_\5WXH`
M`(/X_W1_2)A(@_@'=EI(C40#^$@YV')02(T5X8L``.L0#Q^``````$B#Z`%(
M.=AR-TB+"D@Y"'7O2"G82`'H2(N4)`@``0!D2"L4)2@```!U3TB!Q!```0!;
M74%<PV8N#Q^$``````!(@>T```$`2(']``#__P^%7/___TC'P/_____KNDB-
M/8@L```QP.@5_O__2(T];2P``#'`Z`?^____%>F)``"02(/L"/\5IHD``(G'
M_Q6.B@``2(7`=`-(BP!(@\0(PY!!54%43(TE32P``%5(B?U,B>=32(/L&&1(
MBP0E*````$B)1"0(,<!(C70D!.B?[O__2(7`=`B`.`!(B<-U*DB+1"0(9$@K
M!"4H````=7%(B>Y(@\083(GG,<!;74%<05WI._'__P\?`$B)[_\59XH``$B)
MWTF)Q?\56XH``$F-?`4"_Q48B0``28G82(GJ2(T-^BH``$F)Q4B)QTB--?@K
M```QP/\5YHD``$B+1"0(9$@K!"4H````=05,B>[KDO\5`XD``&9F+@\?A```
M````05=(C0V6*P``28G_2(T]EBH``$%69D@/;L%(C0T9*P``055!5%532('L
M>`$``&1(BP0E*````$B)A"1H`0``2(T%82H``$B-;"0<2,=$)#``````2,>$
M)(@`````````2(GN2,=$)%``````9D@/;LA(C04L*P``9@]LP69(#V[02(T%
M)"L```\I1"0@9D@/;L%F2`]NV$B-#;DJ``!F#VS"2(T%#"L```\11"1H9D@/
M;L%F2`]NX$B-#?$J``!F#VS#,<`/$40D>&9(#V[!9@]LQ`\I1"1`Z"/M__](
MA<!T#(`X`$B)PP^%@@0``/\5S(<``(G'_Q6TB```2(7`#X3;`P``3(LH387M
M#X3/`P``3(GO_Q7NB```2(U\``'_%:N'``!!#[95`$B)!"1)B<:$TG0M3(TE
M@BH```\?0`!)@\4!#[;23(GW3(GF,<!)@\8"_Q5GB```00^V50"$TG7>3(UL
M)&!(C3W3*0``ZPU)BWT(28/%"$B%_W0[2(GN,<#H>>S__TF)Q$B%P'3A@#@`
M=-Q(B<?H-.W__X7`=-!,B>?_%=^'``!(B<-(A<!U/P\?@`````!,C60D($F+
M'"1(A=MT*H`[``^$`0,``$B)W^CY[/__A<`/A?D```!)BUPD"$F#Q`A(A=MU
MV0\?`$B)W_\5#X@``$R+-"1)B<1,B??_%?^'``!!C80$!`0``$QCX$R)Y_\5
MLX8``$V)\4R--9HH``!(B=I)B<5(B<=(C361*0``,<!,C06#*0``3(GQ_Q5W
MAP``OL`!``!,B>__%>&'``"#^/]U$_\5AH<``$2+`$&#^!$/A=\"``!(C;0D
MD````$R)[_\5P(8``(G#A<!T>DF+%TB+/=B#``!,B>DQP$B-->0I``#_%7:&
M``!%,>1(BX0D:`$``&1(*P0E*`````^%)`0``$B!Q'@!``!,B>!;74%<05U!
M7D%?PP\?@`````!(B=])@\0(_Q6CA@``2(G#2(7`#X3,_O__Z?K^__]F+@\?
MA```````BX0DJ````"4`\```/0!````/A6____^+A"2L````B00D_Q69A0``
M.00D#X56____BX0DJ````"7_`0``/<`!```/A3____],B>?_%8"%``!(B>Y(
MC3TY*```28G$,<#HG.K__TB%P`^$0P(``$F+/TB)QNA8\?__2(D$)$B%P`^$
M*P(``$B+/"3_%7F&``!(B<*#^`-^24B+#"1(F$B)5"0(2(TU*"@``$B-?`'\
M_Q7TA0``A<!U*$B+5"0(@_H$#X38`@``2(L,)(U"^TB8@#P!+P^$Q0(```\?
M@`````!(B>Y(C2T6)P``,<!(B>_H#.K__TB%P`^$PP$```^V`(3`#X2X`0``
M/#`/A+`!``!(B>](C353)P``,<#HK^S__TR-/>TG``!(C2W4)P``_Q5CA```
M3(GQ3(GJ3(GG08G`3(T-S2<``$B--:8G```QP/\5:84``.L]#Q^``````/\5
M@H4``(,X$74^_Q4GA```@\,!2(/L"$R)ZD%708G`08G93(GQ2(GN3(GG,<#_
M%2R%``!86K[``0``3(GG_Q64A0``@_C_=+=,B>__%::%``!,B>9(C3WM)0``
M,<#H#>S__TR)Y^AE^O__Z=7]__\QV^D9_?__9@\?A```````2(M\)$!(C5PD
M0$B%_W0BD#'`2(GNZ`;I__](A<!T!8`X`'4T2(M["$B#PPA(A?]UW[\-````
M3(TM>R8``/\5K8,``+I3````2(D$)$F)QND!_/__#Q]``$B)Q_\51X0``$F)
MQ4B%P'2[Z</[__])BQ=(BST0@0``3(GI,<!(C37<)@``_Q6N@P``Z3/]__^0
M2(G'Z+CY__](BX0D:`$``&1(*P0E*`````^%40$``$B!Q'@!``!(B=];74%<
M05U!7D%?_R7?@P``#Q^``````$F+!TB)!"3IR?W__P\?0`!(BSPD,?8QP/\5
M0H0``$&)QX7`#X0W_O__B<?H\/?__TB%P`^()_[__S'22(UP]D2)_TB)!"3_
M%?2"``!(C;0D*@$``+H&````1(G__Q4V@P``2(L,)$B#^`8/A<8```"!O"0J
M`0```$-!0P^%W_W__V:!O"0N`0``2$4/A<_]__](C9PD,`$``#'22(UQSD2)
M__\5F((``+HH````2(G>1(G__Q7?@@``2(/X*'5WQH0D6`$```!)B=A,B?$Q
MP$R-#8\E``!,B>I(C356)0``3(GG_Q4G@P``Z0O^__]-BW\(387_#X0U_?__
M3(G__Q54@P``2(/X`P^&(OW__TF-?`?\2(TU#"4``/\5V((``(7`3`]%/"1,
MB3PDZ0#]____%1*"``!(C3WN)```,<#H'/;__V9F+@\?A```````D$%52(T]
MVR,``$%455-(@^P82(L=X((``&1(BP0E*````$B)1"0(,<!,C60D!$R)YF1(
MBRL/MH6P````B(6Q````,<#HN.;__TB%P'0)@#@Q#X1J`0``,<#HX_#__V1(
MBRM(B>^Y`P```+H!````2(TUGR0``/\538(``$B)Q4B%P'0I2(M`$&1(BSM(
MC16$)```2(LP_Q5U@0``2(M%$$B+,/9&#D`/A50!``!D2(L[N0,```"Z`0``
M`$B--5HD``#_%0&"``!(B<5(A<!T+DR)YDB-/=DB```QP.@@YO__2(G"2(7`
M#X3D````2(M%$&1(BSM(BS#_%1.!``!D2(L[N@$```!(C340)```_Q5E@0``
M9$B+.TB-%10D``!(B<;_%>F```!D2(L#2(T]=R(``$R)YL:`L0`````QP.B]
MY?__2(D%KH(``$B)QTB%P'0^OL`!``#_%=N!``"-4`&#^@%V"8/X$0^%H0``
M`$B+1"0(9$@K!"4H````#X7%````2(/$&%M=05Q!7<,/'P!(BSUI@@``Z&3W
M__](B055@@``2(G'2(7`=:=(C3TF)```,<#_%;Y_``!F#Q]$``"`>`$`#X27
M_O__Z8?^__^0Z+OJ__])B<5(A<!T6TB+11!D2(L[3(GJ2(LP_Q4?@```3(GO
M_Q5>@0``Z?[^__^09$B+._\5GG\``.F=_O__B<%(BP7H@0``2(L5V8$``$B-
M/=HC``!(BS`QP/\51W\```\?@`````!(BP7!@0``2(L0Z:7^____%:M_```/
M'P!54TB)^TB-/:0A``!(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z(;D__](
MA<!T'`^V$(#Z,`^4P(32#Y3""-!U"DB%VW0%@#L`=1U(BT0D"&1(*P0E*```
M`'5Q2(/$&%M=PV8/'T0``$B)W^A@[?__OB\```!(B<5(B<?_%3=_``!(C5`!
M2(7`2`]%ZDB)[_\5HW\``+H$````2(TUTB$``$B)Q_\55G\``(7`=9U(BT0D
M"&1(*P0E*````'4.2(/$&$B)WUM=Z43E____%=9^``!F+@\?A```````#Q]`
M`$%72(G^3(U'.$%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<!(
MB>),C8PD@````$B)UP\?@`````!!BP!-BQ!(@\<028/`"`_(B<!,B=%(B4?P
M3(G02,'I($C!Z"A)P>HX)0#_``!,"=!)B<I(P>$(2<'B&('A``#_`$6)TDP)
MT$@)R$B)1_A,.<]UK68/;TPD$&8/;UPD($B-1"1H2('":`(``&8/;U0D,&8/
M;RWG7P``#Q^``````/,/;P!F#V_B9@]O4-A(@\`09@_O2(AF#^_"9@_OP68/
M;\AF#W/0'V8/<_$!9@_KP68/;\MF#V_<9@_;Q0\I0`A(.=!UNTR+#DR+7A!(
MBWX@2(M>&$R)R$R)RDB+;@A(BTPD"$C!ZAM(P>`%2`G0`P0D2(V,"YEY@EJ-
ME#B9>8):3(G82#'82"'H2#'8C3P"2(GJ2(GH2,'H`DC!XAY)B?I("<),B=A)
MP>H;08G03#'`3"'(3#'82`'(2(GY2,'A!4P)T4R+5"001(TD"$R)R$R)R4C!
MZ0)(P>`>3XV4$YEY@EI-B>5("<A)P>T;2#'"B<%((?I,,<),`=)-B>))P>(%
M30GJ3(ML)!A!`=)(B?I(P>\"2,'B'D6)TD^-A"B9>8):2`GZ38G52#'0B==,
M(>!)P>T;2#'(3`'`38G02<'@!4T)Z$R+;"0@00'`3(G@2<'L`DC!X!Y%B<!*
MC8PIF7F"6DP)X$V)Q4@QPDG![1M!B<1,(=)(,?I(`<I,B<%(P>$%3`GI3(ML
M)"@!T4R)TDG!Z@)(P>(>B<E*C;POF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,
M,>!(`?A(B<](P><%3`GO3(ML)#`!QTR)P$G!Z`)(P>`>B?]/C:0LF7F"6DP)
MP$F)_4@QPDG![1M!B<!((<I,,=),`>))B?Q)P>0%30GL3(ML)#A!`=1(B<I(
MP>D"2,'B'D6)Y$^-E"J9>8):2`G*38GE2#'02<'M&XG12"'X3#'`3`'038GB
M2<'B!4T)ZDR+;"1`00'"2(GX2,'O`DC!X!Y%B=)/C80HF7F"6D@)^$V)U4@Q
MPDG![1N)QTPAXD@QRDP!PDV)T$G!X`5-">A,BVPD2$$!T$R)XDG![`)(P>(>
M18G`2HV,*9EY@EI,">)-B<5(,=!)P>T;08G43"'02#'X2`'(3(G!2,'A!4P)
MZ4R+;"10`<%,B=!)P>H"2,'@'HG)2HV\+YEY@EI,"=!)B<U(,<))P>T;08G"
M3"'"3#'B2`'Z2(G/2,'G!4P)[TR+;"18`==,B<))P>@"2,'B'HG_3XVD+)EY
M@EI,"<))B?U(,=!)P>T;08G02"'(3#'03`'@28G\2<'D!4T)[$R+;"1@00'$
M2(G(2,'@'DC!Z0)%B>1/C90JF7F"6D@)R$V)Y4@QPDG![1N)P4@A^DPQPDP!
MTDV)XDG!X@5-">I,BVPD:$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-
MB=5(,=!)P>T;B==,(>!(,<A,`<!-B=!)P>`%30GH3(ML)'!!`<!,B>!)P>P"
M2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!
MX05,">E,BVPD>`'13(G22,'B'DG!Z@*)R4J-O"^9>8):3`G228G-2#'02<'M
M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BZPD@`````''3(G`2<'H`DC!X!Z)
M_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q&
MC2PB2(G*2,'I`DR+I"2(````2,'B'D@)RD^-E"*9>8):38GL2#'02<'L&XG1
M2"'X3#'`3`'038GJ2<'B!4T)XDR+I"20````00'"2(GX2,'@'DC![P)%B=)/
MC80@F7F"6D@)^$V)U$@QPDG![!N)QTPAZD@QRDP!PDV)T$G!X`5-">!%B<!,
M`<)-B>A)P>T"2<'@'D&)U$T)Z$R+K"28````3#'`3"'02HV,*9EY@EI-B>5(
M,?A)P>T;2`'(3(GA2,'A!4P)Z8G)2`'(3(G12<'J`DC!X1Y!B<5,"=%-B<)%
MB<!),<I$,=),BY0DH````$J-O!>AZ]EN38GJ2`'73(GJ2<'J&TC!X@5,"=*)
MTD@!UTR)XDC!XAY)P>P"08GZ3`.$)*@```!,">))B<R)R4@#C"2P````23'4
M1#'@38VD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$3(GH2<'M`DC!X!Y%
MB>!,">A)B=6)TD@#E"2X````23'%1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A
M!4@)^8G)20'-3(G12<'J`DC!X1Y$B>],"=%)B<*)P$DQRD4QXDZ-I!*AZ]EN
M2(GZ28GZ2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"28G(2`.$
M),````")R4DQT$@#C"3(````13'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)
MP(G`20'%2(GX2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"30````2#''1#'G3(VD
M.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)
MB<*)P$@#A"38````23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG2
M20'53(G"2<'H`DC!XAY%B>I,"<))B<B)R4DQT$@#C"3@````13'@3HVD`*'K
MV6Y,B=!-B=!)P>@;2,'@!4P)P(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)
MTD@#E"3H````2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-
M3(G12<'J`DC!X1Y$B>],"=%)B<*)P$@#A"3P````23'*13'B3HVD$J'KV6Y(
MB?I)B?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQ
MT$4QZ$Z-K`"AZ]EN3(G038G02,'@!4G!Z!M(`XPD^````$P)P(G`20'%2(GX
M2,'O`DC!X!Y%B>A("?A(B=>)TD@#E"0``0``2#''1#'G3(VD.:'KV6Y,B<%,
MB<=(P>\;2,'A!4@)^8G)20',3(G12<'J`DC!X1Y$B>=,"=%)B<*)P$@#A"0(
M`0``23'*13'J3HVL$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'53(G"2<'H
M`DC!XAY%B>I,"<))B<B)R4DQT$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,
M"<!(`XPD$`$``(G`20'$2(GX2,'O`DC!X!Y%B>!("?A(B=>)TD@#E"08`0``
M2#''1#'O3(VL.:'KV6Y,B<%,B<=(P>\;2,'A!4@)^8G)20'-3(G12<'J`DC!
MX1Y$B>],"=%)B<*)P$@#A"0@`0``23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<B)R4DQT$4QZ$Z-K`"A
MZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q4B)^$C!X!Y(P>\"18GH2`.,)"@!
M``!("?A(B=>)TD@#E"0P`0``2#''1#'G38G$2(V,.:'KV6Y,B<=)P>P;2,'G
M!4P)YTV)U$G!Z@))P>0>B?]-"=1)B<)(`?F)P$TQXHG/2`.$)#@!``!%,>I)
MB?U.C902H>O9;DB)^DG![1M(P>(%3`GJ00'23(G"2<'H`DC!XAY%B=),"<)-
MB>!%B>1),=!)B=9!B=5$,<%-B=!(C8P(H>O9;DR)T$G!Z!M(P>`%3`G`1(T$
M`4B)^4C![P*XW+P;CTC!X1Y("?E)"<Z)ST@A^DTAUDD)UDB+E"1``0``2`'"
M3`'B38G$3`'R38G&2<'D!4G![AM-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)
MT4F)UD&)TDDA_DPAP4P)\4R+M"1(`0``20'&30'U38GF3`'I38GE2<'N&TG!
MY05-"?5)B=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+
MM"10`0``20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>
MB?],">)("=%)B=9!B=1-(<9,(>E,"?%,B[0D6`$``$D!QDT!\DF)_DP!T4F)
M^DG![AM)P>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,
M(>I,"?),B[0D8`$``$D!QDT!\$V)UDP!PDV)T$G!X`5)P>X;30GP00'02(GZ
M2,'O`DC!XAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"1H`0``20'&30'T
M38G&3`'A38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4&)
MRDD)SDTAQDPATDP)\DR+M"1P`0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-
M"?5!`=5,B<)(P>(>2<'H`D6)[4P)PD@)T4F)UD&)T$TAUDPAX4P)\4R+M"1X
M`0``20'&3`'W38GN2`'Y3(GO2<'N&TC!YP5,"?=)B=8!STR)X4G![`)(P>$>
MB?],">%!B<Q)"<Y-(>Y,(>),"?),B[0D@`$``$D!QDT!\DF)_DP!TDF)^DG!
M[AM)P>(%30GR00'23(GJ2<'M`DC!XAY%B=),">I("=%)B=9!B=5((?E-(>9,
M"?%,B[0DB`$``$D!QDT!\$V)UDP!P4V)T$G![AM)P>`%30GP28G600'(2(GY
M2,'O`DC!X1Y%B<!("?F)STD)SDTAUD@A^DP)\DR+M"20`0``20'&30'T38G&
M3`'B38G$2<'N&TG!Y`5-"?1!`=1,B=))P>H"2,'B'D6)Y$P)TD@)T4F)UD&)
MTDDA_DPAP4P)\4R+M"28`0``20'&30'U38GF3`'I38GE2<'N&TG!Y05-"?5)
MB=9!`<U,B<%)P>@"2,'A'D6)[4P)P4&)R$D)SDTAYDPAPDP)\DR+M"2@`0``
M20'&3`'W38GN2`'Z3(GO2<'N&TC!YP5,"?<!UTR)XDG![`)(P>(>B?],">)(
M"=%)B=9!B=1-(<9,(>E,"?%,B[0DJ`$``$D!QDT!\DF)_DP!T4F)^DG![AM)
MP>(%30GR28G600'*3(GI2<'M`DC!X1Y%B=),">E!B<U)"<Y)(?Y,(>I,"?),
MB[0DL`$``$D!QDT!\$V)UDP!PDV)T$G![AM)P>`%30GP00'02(GZ2,'O`DC!
MXAY%B<!("?I("=%)B=:)UTTA[DPAT4P)\4R+M"2X`0``20'&30'T38G&3`'A
M38G$2<'N&TG!Y`5-"?1)B=9!`<Q,B=%)P>H"2,'A'D6)Y$P)T4D)SD&)RDTA
MQDPATDP)\DR+M"3``0``20'&30'U38GF3`'J38GE2<'N&TG!Y05-"?5!`=5,
MB<))P>@"2,'B'D6)[4P)PD@)T4F)T$&)UTTAT$PAX4P)P4R+A"3(`0``20'`
M3`''38GH2`'Y3(GO2<'H&TC!YP5,"<=$C00Y3(GG2<'L`DB)T4C!YQY,">=!
MB?Q("?E,(>E,(>)("<I(BXPDT`$``$@!P4P!T4V)PD@#A"38`0``2`'*3(G!
M2<'J&TC!X05,"=&)R4@!RDR)Z4G![0)(P>$>08G23`GI2`G/28G-08G.3"''
M32'E20G]2HT\.$R)T$R+O"3X`0``3`'O38G52,'@!4G![1M,">B)P$@!QTR)
MP$G!Z`)(P>`>08G]20G`N-;!8LI,,<$QT4B+E"3@`0``2`'"3`'B38GL2`'*
M3(GI2<'L&TC!X05,">%-B=2)R4G!Y!Y(`<I)P>H"20''30GB38G$B=%%B<!-
M,=1$,>=,BZ0DZ`$``$D!Q$T!]$F)SDP!YTF)S$G![AM)P>0%30GT38GN2<'M
M`DG!YAY%B>1-"?5,B[0D\`$``$P!YT&)_$D!QDT!\$V)UDTQ[D0Q\DV)YDD!
MT$R)XDG![AM(P>(%3`GRB=))`=!(B<I(P>D"2,'B'D6)QD@)RD2)T4V)ZDDQ
MTDP!^4R+O"0``@``1#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)
MX4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD$`(``$4QZ$V)U4D!
MR$R)T4G![1M)`<=(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"0(
M`@``20'&3`'R38GF23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)
MTDG!Z@)(P>(>08G^20G21(GB28G,B<E,`?I-,=1,B[PD(`(``$4QX$V)]$D!
MT$R)\DG![!M)`<=(P>(%3`GBB=))`=!,B>I)P>T"2,'B'D6)Q$P)ZDR+K"08
M`@``20'%3`'I38G523'51#'O38GE2`'/3(GA2<'M&TC!X05,">F)R4@!STR)
M\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD,`(``$4QT$V)ZDD!
MR$R)Z4G!ZAM(P>$%3`G1B<E)`<A,B>%(P>$>2<'L`D6)PDD!QTP)X4R+I"0H
M`@``20'$3`'B38GT23',1#'G38G42`'73(G22<'L&TC!X@5,">*)TD@!UTR)
MZDG![0)(P>(>08G\20G51(GR28G.B<E-,>Y,`?I,B[PD0`(``$4Q\$V)YDD!
MT$R)XDG![AM(P>(%3`GRB=))`=!,B=))P>H"2,'B'D6)QDP)TDR+E"0X`@``
M20'"3`'138GJ23'21#'738GR2`'/3(GQ2,'A!4G!ZAM)`<=,"=&)R4@!STR)
MX4G![`)(P>$>08GZ20G,1(GI28G5B=)-,>5,`?E,B[PD8`(``$4QZ$V)U4D!
MR$R)T4G![1M(P>$%3`GIB<E)`<A,B?%)P>X"2,'A'D6)Q4P)\4R+M"1(`@``
M20'&3`'R38GF18GD23'.1#'W38GN2`'73(GJ2<'N&TC!X@5,"?*)TD@!UTR)
MTDG!Z@)(P>(>08G^20G22(N4)%`"``!(`<))`=1(B<J)R4PQTDD!QT0QPDV)
M\$D!U$R)\DG!Z!M(P>(%3`G"B=))`=1,B>I)P>T"2,'B'D6)X$P)ZDR+K"18
M`@``20'%3`'I38G523'51#'O38G%2`'/3(G!2<'M&TC!X05,">F)R4@!STR)
M\4G![@)(P>$>08G]20G.1(G128G2B=)-,?),`?E,B[PD<`(``$4QXDV)[$P!
MT4V)ZDG![!M)P>(%30GB38G$18G22<'D'DP!T4G!Z`))`<=-">!,BZ0D:`(`
M`$&)RDD!Q$@#A"1X`@``3`'B38GT3`'(33'$1#'G38G42`'73(G22<'L&TC!
MX@5,">)-B>Q)P>T"2<'D'HG230GE18GT38G&2`'733'NB?I-`?Q%B<!$,?%)
MB=9,`<!-B>A,`>%)B=1)P>X;2<'D!4T)]$0!X4V)U$G!Z@))P>0>B<E-">)-
M,=!$,<=)B<A(`?A(B<](P><%2<'H&P'I00':3`G'1`-N($B)3@@!^$R)5AA(
MB09(B=!(P>H"2,'@'DR);B!("=!$`=A(B4802(N$)(@"``!D2"L$)2@```!U
M$DB!Q)@"``!;74%<05U!7D%?P_\576@```\?1```2(/L"+^`````_Q4A:```
M9@]O!2E*``!(QT`P``````\1`&8/;P4F2@``QT!X``````\10!!F#V\%(TH`
M``\10"!(@\0(PV8N#Q^$``````!!5TACPDF)]T%628G^055!5$F)Q%5)C6XX
M4TB#[!A(BW\H28M6,(T,QT@Y^4EC?GA)B4XH2(/2`$C!Z!U(`=!)B48PA?]T
M;T&]0````$F-;CA!*?U%.>5%#T_L2`'O26/52#GW#X,F`0``2(T$%T@YQ@^"
M*\G__TB-'!9,B?[_%2QG``!!BT9X1`'H08E&>(/X0'042(/$&%M=05Q!74%>
M05_##Q]$``!,B?=%*>Q)B=_HBNC__T&#_#]^?$F-1GA,B?M-C6]`2(E$)`CK
M4&:02(M$)`A(.<,/@E<!``!-B>_S#V\#3(GW08/L0$B#PT!)@\5`#Q%%`/,/
M;TO0#Q%-$/,/;U/@#Q%5(/,/;UOP#Q%=,.@HZ/__08/\/WX:2#G=<JU-B>](
M.>MSMDPY[7.QZ6W(__\/'P!)8\1,.?UR0$DY[W,-28T4!T@YU0^"4,C__TB#
M^`AS6*@$#X7`````2(7`#X67````18EF>$B#Q!A;74%<05U!7D%?PP\?0`!(
MC50%`$DYUW/(Z1/(__^02(T<%D@Y_@^#WO[__T@YWP^#U?[__^GWQ___#Q]$
M``!)BQ=(C4T(3(G^2(/A^$F)5CA)BU0'^$B)5`7X2"G-2`'H2"GN2(/@^$B#
M^`ARBDB#X/@QTDB+/!9(B3P12(/""$@YPG+O18EF>.EN____D$$/MA=!B%8X
MJ`(/A%G___]!#[=4!_YFB50%_NE)____08L708E6.$&+5`?\B50%_.DT____
MZ6C'__]F#Q]$``!!5DR-=CA!54%454B)_5-,BVXH2(GS3(MF,$R)Z$C!Z`.#
MX#^-4`'&1`8X@$ACRH/Z.`^.@`$``+Y`````3`'Q*=9T#S'`B<*#P`'&!!$`
M.?!R\TB)W^BEYO__9@_OP`\10SA)QT8P`````$$/$48000\11B!,B>)!#[;%
M3(GO3(GN2,'J&$C!X`A,B>%(P>\028G03(GJ2,'N&`^VUD`/MO]`#[;V2,'I
M$$@)T$R)X@^VR4C!X`A("?@/MOY!#[;02,'@"$@)\$$/MO1(P>`(2`GP2,'@
M"$@)^$B)WTC!X`A("<A(P>`(2`G02(E#<.@,YO__2(L#2(G?2,'H&(A%`$B+
M`TC!Z!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#
M"(AE!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(
M10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H
M&(A%$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;74%<05U!7O\E<V4```\?
M`+@X````20'.,?\IT(/X"')'28U."(G"2<<&`````$G'1!;X`````$B#X?A)
M*<Y$`?"#X/B#^`@/@H#^__^#X/@QTHG6@\((2(D\,3G"<O/I:?[__P\?0`"H
M!'4DA<`/A%G^__]!Q@8`J`(/A$W^__\QTF9!B50&_NE`_O__#Q\`0<<&````
M`$''1`;\`````.DH_O__4%C#````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P`N`%!!4E]414U0`%!!
M4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),
M24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?
M1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]4
M35!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X
M`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`'-H;W)T(')E860`)7,E<V-A8VAE
M+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P
M`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8S`"UE`"TM````)7,Z(&-R96%T
M:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\]
M)6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A
M9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N
M*0H```````!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y
M("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!
M4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I
M.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F
M9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE
M(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN
M9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`]
M(#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P
M;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@
M("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW
M:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF
M("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*
M<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E
M='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE
M+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2![
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*
M<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA
M;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE
M<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B
M('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD
M:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7
M:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]
M/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM
M>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N
M+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P
M87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K
M"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA
M;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY
M("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M
M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O
M('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@
M/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@
M(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@
M.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@
M)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R
M;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S
M*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@
M*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@
M>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N
M(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A
M9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE
M<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?
M<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D
M4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,[
M"GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P
M;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N
M9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F
M(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B
M*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@
M9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM
M>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F
M<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?
M;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@
M(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H
M<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]
M("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U
M;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ
M+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A
M;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]
M"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I
M<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\[
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5]
M(#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP
M(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M
M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@
M)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E
M;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A
M(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER
M92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@
M)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@
M;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@
M)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<
M+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]
M"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F
M;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@
M*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@
M)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P
M87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?
M<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2![
M"G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%2
M1U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?
M=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/
M0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP
M=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V
M86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P
M87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#([
M"GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L
M<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D
M,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2![
M"F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L
M;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R
M(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F
M:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL
M92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^
M(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@
M/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P
M87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A
M;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@
M)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE
M72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T
M(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O
M9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L
M;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F
M:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D
M7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z
M.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L
M97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@
M)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI
M('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D
M:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F
M(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F
M+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N
M;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK
M.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?
M97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN
M+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D
M8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^
M>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H
M+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B
M.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N
M86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN
M*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN
M97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R
M:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R
M:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C
M;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL
M"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&
M24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE
M(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H
M)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC
M;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H
M(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!
M+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D[
M"G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S
M=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A
M8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?
M;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT
M96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U
M-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T
M7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP
M(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO
M*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H
M)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H
M($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA
M;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H
M:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@
M*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?
M;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R
M7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C
M:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q
M.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!
M4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F
M("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H
M<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E
M>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT
M<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L*
M*"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T
M:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!]
M.PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E
M;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%
M3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-
M4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D
M969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U
M<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED
M*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO
M9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]
M"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60[
M"GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[
M55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#
M3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E
M;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F
M:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@
M,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I
M.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P
M;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@
M)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N
M86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H
M92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*
M?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL
M87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@
M*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@
M/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*
M;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@
M)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E
M;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B
M)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E
M9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@
M=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P
M*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N
M(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2![
M"B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!
M5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER
M(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<
M120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E
M;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@
M)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N
M)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@
M)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I
M;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M
M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI
M;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@
M1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D
M14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*
M<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R
M:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]
M"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD
M;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N
M('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER
M96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*
M0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*
M0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?
M7T5.1%]?"@``0T%#2$4``'!E<FQX<VDN8P````````#_____`````/____\`
M`````2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````
M`````````1L#.^P````<````8'___P@!``"`?___C`(``()___]D!@``D'__
M_V@%``#P@O__,`$``,"#__]\`0``4(3__Z`!``#`A?__W`$```"(__\H`@``
M4(C__T0"``"`B/__6`(``+")__^D`@``P(G__[@"``#@B___"`,``!",__\D
M`P``,(W__V`#``"0D?__K`,```"2___(`P``P)+__^0#````E/__)`0``""4
M__\\!```\)3__W@$``#PF___]`0``$">__\P!0``()___Y@%``"0M?__Z`4`
M`."U__\`!@``(+C__X0&````````%``````````!>E(``7@0`1L,!PB0`0``
M)````!P```!0?O__(``````.$$8.&$H/"W<(@``_&CLJ,R0B`````$@```!$
M````N('__\P`````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y`
M`FT*#CA$#C!!#BA"#B!"#AA"#A!"#@A("P`@````D````#R"__^$`````$$.
M$(,"2@ZP`0)Q"@X000X(00LX````M````*B"__]M`0```$(.$(T"0@X8C`-!
M#B"&!$$.*(,%1P[0`7X*#BA!#B!!#AA"#A!"#@A'"P!(````\````-R#__\R
M`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.8`,5`0H..$$.
M,$$.*$(.($(.&$(.$$(."$4+&````#P!``#0A?__30````!!#A"#`G(."```
M`!````!8`0``!(;__R8`````````,````&P!```@AO__*@$```!!#A"&`D$.
M&(,#1PZ8($P.F$!)#L!``N(*#AA$#A!!#@A+"Q0```"@`0``['S__P(`````
M#L!`@P.&`A````"X`0``!(?__P4`````````3````,P!````A___'P(```!"
M#A"/`D(.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#K@@3`[P(0)R"@XX00XP
M00XH0@X@0@X80@X00@X(1PL8````'`(``-"(__\D`````$$.$(,"70X(````
M.````#@"``#DB/__$@$```!!#A"&`D$.&(,#1PZ8($D.L"`"L@H.&$$.$$$.
M"$H+6@H.&$@.$$$."$T+2````'0"``#(B?__700```!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&2`XX@P=$#E`#`@0*#CA-#C!!#BA"#B!"#AA"#A!"#@A%
M"Q@```#``@``W(W__V(`````1`X@`E`*#@A$"P`8````W`(``#".__^Q````
M`$$.$$$."$<.X`$`/````/@"``#4CO__/P$```!"#A",`D$.&(8#00X@@P1(
M#`N@@`11#0=$#K"`!`+0"@X@00X800X00@X(2PL``!0````X`P``U(___Q\`
M````1`X06@X(`#@```!0`P``W(___\4`````0@X0C0)"#AB,`T@.((8$1PXH
M@P5$#D!^"@XH1@X@00X80@X00@X(2`L``'@```",`P``<)#___0&````0@X0
MCP)3#AB.`TX.((T$0@XHC`5!#C"&!D$..(,'1PZP`P.5`@H..$0.,$$.*$(.
M($(.&$(.$$(."$@+`Z`!#K@#10[``U@.N`-!#K`#`P`!"@XX1`XP00XH0@X@
M0@X80@X00@X(30L````X````"`0``/26__]-`@```$(.$(T"20X8C`-!#B"&
M!$$.*(,%1`Y``W4!"@XH00X@00X80@X00@X(1`LT````1`0```B9___2````
M`$$.$(8"00X8@P-.#C`"3PH.&$$.$$$."$<+`EH*#AA$#A!!#@A%"RP```!\
M!```('K__Q4"````00X0A@)!#AB#`T0.4`-Q`0H.&$,.$$$."$$+`````$P`
M``"L!```@)G__VL6````0@X0CP))#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'
M1P[0!0-"%@H..$$.,$$.*$(.($(.&$(.$$(."$$+````%````/P$``"@K___
M1@````!$#A`"00X(8````!0%``#8K___.@(```!"#A"/`D@.&(X#10X@C01"
M#BB,!40.,(8&10XX@P=$#E`">@H..$$.,$$.*$(.($(.&$(.$$(."$8+`LD*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A%"QP```!X!0``%GG__P(`````#E"#!X8&
MC`6-!(X#CP(`/````)@%``"4L?__30(```!"#A".`D8.&(T#0@X@C`1!#BB&
M!40.,(,&`YD!"@XH00X@0@X80@X00@X(20L`````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````!@(P`````````C```````````````````!````````
M`-`"`````````0````````#;`@```````!T`````````#@0````````,````
M```````@````````#0`````````=6P```````!D`````````^+L````````;
M``````````@`````````&@``````````O````````!P`````````"```````
M``#U_O]O`````)`#````````!0````````"(#0````````8`````````B`0`
M```````*`````````"P$````````"P`````````8`````````!4`````````
M```````````#`````````/"]`````````@`````````8`````````!0`````
M````!P`````````7`````````#`8````````!P````````"X$0````````@`
M````````>`8````````)`````````!@`````````'@`````````(````````
M`/O__V\``````0``"`````#Y__]O``````0`````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````0O```````````````````````````
M```F(```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````P`````````I005(N<&T*``````````#H8@```````$=#
M0SH@*$%L<&EN92`Q,RXR+C%?9VET,C`R-#`S,#DI(#$S+C(N,2`R,#(T,#,P
M.0``+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E
M+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?
M9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M9&%T82YR96PN<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M````````````````````````````````````````````````````````````
M````````````````````````````````````"P````$````"`````````!@#
M````````&`,````````9`````````````````````0``````````````````
M`!,````'`````@`````````X`P```````#@#````````,```````````````
M``````@````````````````````F````!P````(`````````:`,```````!H
M`P```````"0````````````````````$````````````````````.0```/;_
M_V\"`````````)`#````````D`,```````#T``````````4`````````"```
M`````````````````$,````+`````@````````"(!````````(@$````````
M``D````````&`````0````@`````````&`````````!+`````P````(`````
M````B`T```````"(#0```````"P$```````````````````!````````````
M````````4P````0````"`````````+@1````````N!$```````!X!@``````
M``4`````````"``````````8`````````%T````$````0@`````````P&```
M`````#`8````````&``````````%````%`````@`````````&`````````!G
M`````0````8``````````"``````````(`````````,`````````````````
M```!````````````````````8@````$````&`````````!`@````````$"``
M```````@````````````````````$``````````0`````````&T````!````
M!@`````````P(````````#`@````````[3H``````````````````!``````
M``````````````!S`````0````8`````````'5L````````=6P````````,`
M```````````````````!````````````````````>0````$````"````````
M``!@`````````&````````"P0```````````````````$```````````````
M`````($````!`````@````````"PH````````+"@````````[```````````
M``````````0```````````````````"/`````0````(`````````H*$`````
M``"@H0```````-@%```````````````````(````````````````````F0``
M``X````#`````````/B[````````^*L````````(````````````````````
M"``````````(`````````*4````/`````P``````````O`````````"L````
M````"`````````````````````@`````````"`````````"Q`````0````,`
M````````"+P````````(K`````````@````````````````````(````````
M````````````O@````8````#`````````!"\````````$*P```````#@`0``
M``````8`````````"``````````0`````````,<````!`````P````````#P
MO0```````/"M````````$`(```````````````````@`````````"```````
M``#,`````0````,``````````,``````````L````````"``````````````
M```````(````````````````````T@````@````#`````````"#`````````
M(+````````"0````````````````````(````````````````````-<````!
M````,````````````````````""P````````,0````````````````````$`
M`````````0`````````!`````P````````````````````````!1L```````
A`.`````````````````````!````````````````````
